@@ -18,7 +18,7 @@ package commons
 
 import (
 	"encoding/json"
-	"io/ioutil"
+	"os"
 	"reflect"
 	"regexp"
 	"strings"
@@ -148,7 +148,7 @@ func (r *RefResolver) ResolveVarRefFromParentModuleCall(varRef, callerRef string
 	}
 
 	// read source file
-	fileBytes, err := ioutil.ReadFile(r.ParentModuleCall.SourceAddrRange.Filename)
+	fileBytes, err := os.ReadFile(r.ParentModuleCall.SourceAddrRange.Filename)
 	if err != nil {
 		zap.S().Errorf("failed to read terrafrom IaC file '%s'. error: '%v'", r.ParentModuleCall.SourceAddr, err)
 		return varRef
