@@ -20,7 +20,8 @@ import (
 	"encoding/base64"
 	"unicode"
 
-	"github.com/awslabs/goformation/v5/cloudformation/autoscaling"
+	"github.com/awslabs/goformation/v6/cloudformation/autoscaling"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // EbsBlockDeviceBlock holds config for EbsBlockDevice
@@ -48,38 +49,41 @@ type AutoScalingLaunchConfigurationConfig struct {
 
 // GetAutoScalingLaunchConfigurationConfig returns config for AutoScalingLaunchConfiguration
 func GetAutoScalingLaunchConfigurationConfig(l *autoscaling.LaunchConfiguration) []AWSResourceConfig {
-	ebsBlockDevice := make([]EbsBlockDeviceBlock, len(l.BlockDeviceMappings))
-
-	for i := range l.BlockDeviceMappings {
-		if l.BlockDeviceMappings[i].Ebs != nil {
-			ebsBlockDevice[i].Encrypted = l.BlockDeviceMappings[i].Ebs.Encrypted
-			ebsBlockDevice[i].DeleteOnTermination = l.BlockDeviceMappings[i].Ebs.DeleteOnTermination
+	var ebsBlockDevice []EbsBlockDeviceBlock
+	if l.BlockDeviceMappings != nil {
+		blockDeviceMappingLen := len(functions.GetVal(l.BlockDeviceMappings))
+		ebsBlockDevice = make([]EbsBlockDeviceBlock, blockDeviceMappingLen)
+		for i, blockDeviceMapping := range functions.GetVal(l.BlockDeviceMappings) {
+			if blockDeviceMapping.Ebs != nil {
+				ebsBlockDevice[i].Encrypted = functions.GetVal(blockDeviceMapping.Ebs.Encrypted)
+				ebsBlockDevice[i].DeleteOnTermination = functions.GetVal(blockDeviceMapping.Ebs.DeleteOnTermination)
+			}
+			ebsBlockDevice[i].DeviceName = blockDeviceMapping.DeviceName
 		}
-		ebsBlockDevice[i].DeviceName = l.BlockDeviceMappings[i].DeviceName
 	}
 
 	var metadataOptions MetadataOptionsBlock
 	if l.MetadataOptions != nil {
-		metadataOptions.HTTPEndpoint = l.MetadataOptions.HttpEndpoint
-		metadataOptions.HTTPTokens = l.MetadataOptions.HttpTokens
+		metadataOptions.HTTPEndpoint = functions.GetVal(l.MetadataOptions.HttpEndpoint)
+		metadataOptions.HTTPTokens = functions.GetVal(l.MetadataOptions.HttpTokens)
 	}
 
 	cf := AutoScalingLaunchConfigurationConfig{
 		Config: Config{
-			Name: l.LaunchConfigurationName,
+			Name: functions.GetVal(l.LaunchConfigurationName),
 		},
-		EnableMonitoring: l.InstanceMonitoring,
+		EnableMonitoring: functions.GetVal(l.InstanceMonitoring),
 		MetadataOptions:  metadataOptions,
 		EbsBlockDevice:   ebsBlockDevice,
 	}
 
-	data, err := base64.StdEncoding.Strict().DecodeString(l.UserData)
+	data, err := base64.StdEncoding.Strict().DecodeString(functions.GetVal(l.UserData))
 	datastr := string(data)
 
 	if isASCII(datastr) && err == nil {
-		cf.UserDataBase64 = l.UserData
+		cf.UserDataBase64 = datastr
 	} else {
-		cf.UserData = l.UserData
+		cf.UserData = datastr
 	}
 
 	return []AWSResourceConfig{{
