@@ -16,7 +16,10 @@
 
 package config
 
-import "github.com/awslabs/goformation/v5/cloudformation/codebuild"
+import (
+	"github.com/awslabs/goformation/v6/cloudformation/codebuild"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
+)
 
 // ArtifactBlock holds config for ArtifactBlock
 type ArtifactBlock struct {
@@ -74,7 +77,7 @@ func GetCodebuildProjectConfig(p *codebuild.Project) []AWSResourceConfig {
 		cacheBlock = make([]CacheBlock, 1)
 
 		cacheBlock[0].Type = p.Cache.Type
-		cacheBlock[0].Modes = p.Cache.Modes
+		cacheBlock[0].Modes = *p.Cache.Modes
 	}
 
 	var environmentBlock []CodebuildEnvironmentBlock
@@ -84,7 +87,7 @@ func GetCodebuildProjectConfig(p *codebuild.Project) []AWSResourceConfig {
 		environmentBlock[0].ComputeType = p.Environment.ComputeType
 		environmentBlock[0].Image = p.Environment.Image
 		environmentBlock[0].Type = p.Environment.Type
-		environmentBlock[0].ImagePullCredentialsType = p.Environment.ImagePullCredentialsType
+		environmentBlock[0].ImagePullCredentialsType = functions.GetVal(p.Environment.ImagePullCredentialsType)
 	}
 
 	var sourceBlock []SourceBlock
@@ -92,20 +95,20 @@ func GetCodebuildProjectConfig(p *codebuild.Project) []AWSResourceConfig {
 		sourceBlock = make([]SourceBlock, 1)
 
 		sourceBlock[0].Type = p.Source.Type
-		sourceBlock[0].Location = p.Source.Location
-		sourceBlock[0].GitCloneDepth = p.Source.GitCloneDepth
+		sourceBlock[0].Location = functions.GetVal(p.Source.Location)
+		sourceBlock[0].GitCloneDepth = functions.GetVal(p.Source.GitCloneDepth)
 	}
 
 	cf := CodebuildProjectConfig{
 		Config: Config{
-			Name: p.Name,
+			Name: functions.GetVal(p.Name),
 		},
-		Name:          p.Name,
-		Description:   p.Description,
-		BuildTimeout:  p.TimeoutInMinutes,
-		QueuedTimeout: p.QueuedTimeoutInMinutes,
+		Name:          functions.GetVal(p.Name),
+		Description:   functions.GetVal(p.Description),
+		BuildTimeout:  functions.GetVal(p.TimeoutInMinutes),
+		QueuedTimeout: functions.GetVal(p.QueuedTimeoutInMinutes),
 		ServiceRole:   p.ServiceRole,
-		EncryptionKey: p.EncryptionKey,
+		EncryptionKey: functions.GetVal(p.EncryptionKey),
 		Artifacts:     artifactBlock,
 		Cache:         cacheBlock,
 		Environment:   environmentBlock,
