@@ -16,7 +16,10 @@
 
 package config
 
-import "github.com/awslabs/goformation/v5/cloudformation/dms"
+import (
+	"github.com/awslabs/goformation/v6/cloudformation/dms"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
+)
 
 // DmsReplicationInstanceConfig holds config for DmsReplicationInstance
 type DmsReplicationInstanceConfig struct {
@@ -42,18 +45,18 @@ func GetDmsReplicationInstanceConfig(r *dms.ReplicationInstance) []AWSResourceCo
 			Tags: r.Tags,
 		},
 
-		AlocatedStorage:            r.AllocatedStorage,
-		AutoMinorVersionUpgrade:    r.AutoMinorVersionUpgrade,
-		AvailabilityZone:           r.AvailabilityZone,
-		EngineVersion:              r.EngineVersion,
-		KMSKeyARN:                  r.KmsKeyId,
-		MultiAZ:                    r.MultiAZ,
-		PreferredMaintenanceWindow: r.PreferredMaintenanceWindow,
-		PubliclyAccessible:         r.PubliclyAccessible,
+		AlocatedStorage:            functions.GetVal(r.AllocatedStorage),
+		AutoMinorVersionUpgrade:    functions.GetVal(r.AutoMinorVersionUpgrade),
+		AvailabilityZone:           functions.GetVal(r.AvailabilityZone),
+		EngineVersion:              functions.GetVal(r.EngineVersion),
+		KMSKeyARN:                  functions.GetVal(r.KmsKeyId),
+		MultiAZ:                    functions.GetVal(r.MultiAZ),
+		PreferredMaintenanceWindow: functions.GetVal(r.PreferredMaintenanceWindow),
+		PubliclyAccessible:         functions.GetVal(r.PubliclyAccessible),
 		ReplicationInstanceClass:   r.ReplicationInstanceClass,
-		ReplicationInstanceID:      r.ReplicationInstanceIdentifier,
-		ReplicationSubnetGroupID:   r.ReplicationSubnetGroupIdentifier,
-		VPCSecurityGroupIDs:        r.VpcSecurityGroupIds,
+		ReplicationInstanceID:      functions.GetVal(r.ReplicationInstanceIdentifier),
+		ReplicationSubnetGroupID:   functions.GetVal(r.ReplicationSubnetGroupIdentifier),
+		VPCSecurityGroupIDs:        functions.GetVal(r.VpcSecurityGroupIds),
 	}
 
 	return []AWSResourceConfig{{
