@@ -17,7 +17,8 @@
 package config
 
 import (
-	"github.com/awslabs/goformation/v5/cloudformation/ec2"
+	"github.com/awslabs/goformation/v6/cloudformation/ec2"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // EbsVolumeConfig holds config for aws_ebs_volume
@@ -33,8 +34,8 @@ func GetEbsVolumeConfig(v *ec2.Volume) []AWSResourceConfig {
 		Config: Config{
 			Tags: v.Tags,
 		},
-		Encrypted: v.Encrypted,
-		KmsKeyID:  v.KmsKeyId,
+		Encrypted: functions.GetVal(v.Encrypted),
+		KmsKeyID:  functions.GetVal(v.KmsKeyId),
 	}
 	return []AWSResourceConfig{{
 		Resource: cf,
