@@ -20,7 +20,8 @@ import (
 	"fmt"
 	"strconv"
 
-	"github.com/awslabs/goformation/v5/cloudformation/ec2"
+	"github.com/awslabs/goformation/v6/cloudformation/ec2"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/store"
 )
 
@@ -65,24 +66,26 @@ type EC2InstanceConfig struct {
 
 // GetEC2InstanceConfig returns config for EC2Instance
 func GetEC2InstanceConfig(i *ec2.Instance, instanceName string) []AWSResourceConfig {
-	nics := make([]NetworkInterfaceBlock, len(i.NetworkInterfaces))
-	niconfigs := make([]NetworkInterfaceConfig, len(i.NetworkInterfaces))
-	awsconfig := make([]AWSResourceConfig, len(i.NetworkInterfaces))
+	networkInterfaces := functions.GetVal(i.NetworkInterfaces)
 
-	for index := range i.NetworkInterfaces {
-		nics[index].NetworkInterfaceID = i.NetworkInterfaces[index].NetworkInterfaceId
-		nics[index].DeleteOnTermination = i.NetworkInterfaces[index].DeleteOnTermination
+	nics := make([]NetworkInterfaceBlock, len(networkInterfaces))
+	niconfigs := make([]NetworkInterfaceConfig, len(networkInterfaces))
+	awsconfig := make([]AWSResourceConfig, len(networkInterfaces))
+
+	for index, networkInterface := range networkInterfaces {
+		nics[index].NetworkInterfaceID = functions.GetVal(networkInterface.NetworkInterfaceId)
+		nics[index].DeleteOnTermination = functions.GetVal(networkInterface.DeleteOnTermination)
 		var devindex int
-		devindex, err := strconv.Atoi(i.NetworkInterfaces[index].DeviceIndex)
+		devindex, err := strconv.Atoi(networkInterface.DeviceIndex)
 		if err != nil {
 			devindex = 0
 		}
 		nics[index].DeviceIndex = devindex
 
 		// create aws_network_interface resource on the fly for every network interface used in aws_instance
-		niconfigs[index].SubnetID = i.NetworkInterfaces[index].SubnetId
-		if i.NetworkInterfaces[index].PrivateIpAddress != "" {
-			niconfigs[index].PrivateIPs = []string{i.NetworkInterfaces[index].PrivateIpAddress}
+		niconfigs[index].SubnetID = functions.GetVal(networkInterface.SubnetId)
+		if networkInterface.PrivateIpAddress != nil {
+			niconfigs[index].PrivateIPs = []string{functions.GetVal(networkInterface.PrivateIpAddress)}
 		}
 
 		nicname := fmt.Sprintf("%s%d", instanceName, index)
@@ -102,17 +105,17 @@ func GetEC2InstanceConfig(i *ec2.Instance, instanceName string) []AWSResourceCon
 			Tags: i.Tags,
 			Name: instanceName,
 		},
-		AMI:                 i.ImageId,
-		InstanceType:        i.InstanceType,
-		EBSOptimized:        i.EbsOptimized,
-		Monitoring:          i.Monitoring,
-		IAMInstanceProfile:  i.IamInstanceProfile,
-		VPCSecurityGroupIDs: i.SecurityGroupIds,
+		AMI:                 functions.GetVal(i.ImageId),
+		InstanceType:        functions.GetVal(i.InstanceType),
+		EBSOptimized:        functions.GetVal(i.EbsOptimized),
+		Monitoring:          functions.GetVal(i.Monitoring),
+		IAMInstanceProfile:  functions.GetVal(i.IamInstanceProfile),
+		VPCSecurityGroupIDs: functions.GetVal(i.SecurityGroupIds),
 		NetworkInterface:    nics,
 	}
 
 	if i.HibernationOptions != nil {
-		ec2Config.Hibernation = i.HibernationOptions.Configured
+		ec2Config.Hibernation = functions.GetVal(i.HibernationOptions.Configured)
 	}
 
 	var awsconfigec2 AWSResourceConfig
