@@ -17,7 +17,8 @@
 package config
 
 import (
-	"github.com/awslabs/goformation/v5/cloudformation/elasticache"
+	"github.com/awslabs/goformation/v6/cloudformation/elasticache"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // ElastiCacheClusterConfig holds config for aws_elasticache_cluster
@@ -33,11 +34,11 @@ func GetElastiCacheClusterConfig(e *elasticache.CacheCluster) []AWSResourceConfi
 	cf := ElastiCacheClusterConfig{
 		Config: Config{
 			Tags: e.Tags,
-			Name: e.ClusterName,
+			Name: functions.GetVal(e.ClusterName),
 		},
-		AZMode:        e.AZMode,
+		AZMode:        functions.GetVal(e.AZMode),
 		Engine:        e.Engine,
-		EngineVersion: e.EngineVersion,
+		EngineVersion: functions.GetVal(e.EngineVersion),
 	}
 	return []AWSResourceConfig{{
 		Resource: cf,
