@@ -17,7 +17,8 @@
 package config
 
 import (
-	"github.com/awslabs/goformation/v5/cloudformation/globalaccelerator"
+	"github.com/awslabs/goformation/v6/cloudformation/globalaccelerator"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // GlobalAcceleratorConfig holds config for aws_globalaccelerator_accelerator resource
@@ -36,8 +37,8 @@ func GetGlobalAcceleratorConfig(g *globalaccelerator.Accelerator) []AWSResourceC
 			Tags: g.Tags,
 		},
 		Name:          g.Name,
-		Enabled:       g.Enabled,
-		IPAddressType: g.IpAddressType,
+		Enabled:       functions.GetVal(g.Enabled),
+		IPAddressType: functions.GetVal(g.IpAddressType),
 	}
 
 	return []AWSResourceConfig{{
