@@ -16,7 +16,10 @@
 
 package config
 
-import "github.com/awslabs/goformation/v5/cloudformation/ram"
+import (
+	"github.com/awslabs/goformation/v6/cloudformation/ram"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
+)
 
 // RAMResourceShareConfig holds config for RAMResourceShare
 type RAMResourceShareConfig struct {
@@ -33,7 +36,7 @@ func GetRAMResourceShareConfig(r *ram.ResourceShare) []AWSResourceConfig {
 			Tags: r.Tags,
 		},
 		Name:                    r.Name,
-		AllowExternalPrincipals: r.AllowExternalPrincipals,
+		AllowExternalPrincipals: functions.GetVal(r.AllowExternalPrincipals),
 	}
 
 	return []AWSResourceConfig{{
