@@ -17,7 +17,8 @@
 package config
 
 import (
-	"github.com/awslabs/goformation/v5/cloudformation/rds"
+	"github.com/awslabs/goformation/v6/cloudformation/rds"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // RDSClusterConfig holds config for aws_rds_cluster
@@ -31,11 +32,11 @@ type RDSClusterConfig struct {
 func GetRDSClusterConfig(c *rds.DBCluster) []AWSResourceConfig {
 	cf := RDSClusterConfig{
 		Config: Config{
-			Name: c.DatabaseName,
+			Name: functions.GetVal(c.DatabaseName),
 			Tags: c.Tags,
 		},
-		BackupRetentionPeriod: c.BackupRetentionPeriod,
-		StorageEncrypted:      c.StorageEncrypted,
+		BackupRetentionPeriod: functions.GetVal(c.BackupRetentionPeriod),
+		StorageEncrypted:      functions.GetVal(c.StorageEncrypted),
 	}
 	return []AWSResourceConfig{{
 		Resource: cf,
