@@ -17,7 +17,8 @@
 package config
 
 import (
-	"github.com/awslabs/goformation/v5/cloudformation/route53"
+	"github.com/awslabs/goformation/v6/cloudformation/route53"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // Route53RecordConfig holds config for aws_route53_record
@@ -32,7 +33,7 @@ func GetRoute53RecordConfig(r *route53.RecordSet) []AWSResourceConfig {
 		Config: Config{
 			Name: r.Name,
 		},
-		ResourceRecords: r.ResourceRecords,
+		ResourceRecords: functions.GetVal(r.ResourceRecords),
 	}
 	return []AWSResourceConfig{{
 		Resource: cf,
