@@ -16,7 +16,10 @@
 
 package config
 
-import "github.com/awslabs/goformation/v5/cloudformation/sagemaker"
+import (
+	"github.com/awslabs/goformation/v6/cloudformation/sagemaker"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
+)
 
 // ImageConfigBlock holds config for ImageConfig
 type ImageConfigBlock struct {
@@ -44,9 +47,12 @@ type SagemakerModelConfig struct {
 
 // GetSagemakerModelConfig returns config for SagemakerModel
 func GetSagemakerModelConfig(m *sagemaker.Model) []AWSResourceConfig {
-	container := make([]ContainerBlock, len(m.Containers))
-	for i := range m.Containers {
-		container[i] = getContainer(m.Containers[i])
+	var containerBlock []ContainerBlock
+	if m.Containers != nil {
+		containerBlock = make([]ContainerBlock, len(*m.Containers))
+		for i, container := range *m.Containers {
+			containerBlock[i] = getContainer(container)
+		}
 	}
 
 	var primaryContainer []ContainerBlock
@@ -57,12 +63,12 @@ func GetSagemakerModelConfig(m *sagemaker.Model) []AWSResourceConfig {
 
 	cf := SagemakerModelConfig{
 		Config: Config{
-			Name: m.ModelName,
+			Name: functions.GetVal(m.ModelName),
 			Tags: m.Tags,
 		},
-		Name:             m.ModelName,
+		Name:             functions.GetVal(m.ModelName),
 		ExecutionRoleARN: m.ExecutionRoleArn,
-		Container:        container,
+		Container:        containerBlock,
 		PrimaryContainer: primaryContainer,
 	}
 
@@ -75,10 +81,10 @@ func GetSagemakerModelConfig(m *sagemaker.Model) []AWSResourceConfig {
 func getContainer(gftContainer sagemaker.Model_ContainerDefinition) ContainerBlock {
 	var container ContainerBlock
 
-	container.Image = gftContainer.Image
-	container.Mode = gftContainer.Mode
-	container.ModelDataURL = gftContainer.ModelDataUrl
-	container.ContainerHostname = gftContainer.ContainerHostname
+	container.Image = functions.GetVal(gftContainer.Image)
+	container.Mode = functions.GetVal(gftContainer.Mode)
+	container.ModelDataURL = functions.GetVal(gftContainer.ModelDataUrl)
+	container.ContainerHostname = functions.GetVal(gftContainer.ContainerHostname)
 	container.Environment = gftContainer.Environment
 
 	if gftContainer.ImageConfig != nil {
