@@ -17,7 +17,8 @@
 package config
 
 import (
-	"github.com/awslabs/goformation/v5/cloudformation/secretsmanager"
+	"github.com/awslabs/goformation/v6/cloudformation/secretsmanager"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // SecretsManagerSecretConfig holds config for aws_secretsmanager_secret
@@ -31,9 +32,9 @@ func GetSecretsManagerSecretConfig(s *secretsmanager.Secret) []AWSResourceConfig
 	cf := SecretsManagerSecretConfig{
 		Config: Config{
 			Tags: s.Tags,
-			Name: s.Name,
+			Name: functions.GetVal(s.Name),
 		},
-		KmsKeyID: s.KmsKeyId,
+		KmsKeyID: functions.GetVal(s.KmsKeyId),
 	}
 	return []AWSResourceConfig{{
 		Resource: cf,
