@@ -17,7 +17,8 @@
 package config
 
 import (
-	"github.com/awslabs/goformation/v5/cloudformation/sqs"
+	"github.com/awslabs/goformation/v6/cloudformation/sqs"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // SqsQueueConfig holds config for SqsQueue
@@ -33,12 +34,12 @@ type SqsQueueConfig struct {
 func GetSqsQueueConfig(q *sqs.Queue) []AWSResourceConfig {
 	cf := SqsQueueConfig{
 		Config: Config{
-			Name: q.QueueName,
+			Name: functions.GetVal(q.QueueName),
 		},
-		Name:                         q.QueueName,
-		KmsMasterKeyID:               q.KmsMasterKeyId,
-		KmsDataKeyReusePeriodSeconds: q.KmsDataKeyReusePeriodSeconds,
-		MessageRetentionSeconds:      q.MessageRetentionPeriod,
+		Name:                         functions.GetVal(q.QueueName),
+		KmsMasterKeyID:               functions.GetVal(q.KmsMasterKeyId),
+		KmsDataKeyReusePeriodSeconds: functions.GetVal(q.KmsDataKeyReusePeriodSeconds),
+		MessageRetentionSeconds:      functions.GetVal(q.MessageRetentionPeriod),
 	}
 	return []AWSResourceConfig{{
 		Resource: cf,
